Learn R Programming

Langevin (version 1.3.3)

print.Langevin: Print estimated drift and diffusion coefficients

Description

print method for class "Langevin".

Usage

# S3 method for Langevin
print(x, digits = max(3, getOption("digits") - 3), ...)

Value

The function print.Langevin() returns an overview of the estimated drift and diffusion coefficients.

Arguments

x

an object of class "Langevin".

digits

integer, used for number formatting with signif().

...

further arguments to be passed to or from other methods. They are ignored in this function.

Author

Philip Rinn